@@ -22,7 +22,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 // Qt
 #include <QTimer>
-#include <QDebug>
+#include "gwenview_lib_debug.h"
 #include <QUrl>
 
 // KDE
